@@ -105,7 +105,7 @@ class PCA(HasTraits):
         if centered:
             self._center = center = X.mean(dim=0)
             Xsc = X - center
-            Xsc.title = f"centered {X.title}"
+            Xsc.name = f"centered {X.name}"
 
         # Standardization
         # ---------------
@@ -113,7 +113,7 @@ class PCA(HasTraits):
         if standardized:
             self._std = Xsc.std(dim=0)
             Xsc /= self._std
-            Xsc.title = f"standardized {Xsc.title}"
+            Xsc.name = f"standardized {Xsc.name}"
 
         # Scaling
         # -------
@@ -123,7 +123,7 @@ class PCA(HasTraits):
             self._ampl = Xsc.ptp(dim=0)
             Xsc -= self._min
             Xsc /= self._ampl
-            Xsc.title = "scaled %s" % Xsc.title
+            Xsc.name = "scaled %s" % Xsc.name
 
         self._Xscaled = Xsc
 
@@ -258,7 +258,7 @@ class PCA(HasTraits):
         M, N = self._X.shape
 
         if rank > len(spectrum):
-            raise ValueError("The tested rank cannot exceed the rank of the" " dataset")
+            raise ValueError("The tested rank cannot exceed the rank of the dataset")
 
         pu = -rank * np.log(2.0)
         for i in range(rank):
@@ -378,9 +378,39 @@ class PCA(HasTraits):
             X += self._center
 
         X.history = f"PCA reconstructed Dataset with {n_pc} principal components"
+        X.name = self._X.name
         X.title = self._X.title
         return X
 
+    def plotmerit(self, n_pc=None, **kwargs):
+        """
+        Plots the input dataset, reconstructed dataset and residuals.
+
+        Parameters
+        ----------
+        **kwargs
+            optional "colors" argument: tuple or array of 3 colors for :math:`X`, :math:`\hat X` and :math:`E`.
+
+        Returns
+        -------
+        ax
+            subplot.
+        """
+        colX, colXhat, colRes = kwargs.get("colors", ["blue", "green", "red"])
+
+        X_hat = self.reconstruct(n_pc=n_pc)
+        res = self.X - X_hat
+        ax = self.X.plot()
+        if self.X.x is not None:
+            ax.plot(self.X.x.data, X_hat.T.data, color=colXhat)
+            ax.plot(self.X.x.data, res.T.data, color=colRes)
+        else:
+            ax.plot(X_hat.T.data, color=colXhat)
+            ax.plot(res.T.data, color=colRes)
+        ax.autoscale(enable=True)
+        ax.set_title("PCA merit plot")
+        return ax
+
     def printev(self, n_pc=None):
         """
         Print PCA figures of merit.
