@@ -53,7 +53,12 @@ def _integrate_method(method):
             del new._coordset.coords[idx]
 
         new.title = "area"
-        new._units = dataset.units * dataset.coord(dim).units
+        if dataset.units is not None and dataset.coord(dim).units is not None:
+            new._units = dataset.units * dataset.coord(dim).units
+        elif dataset.units is not None:
+            new._units = dataset.units
+        elif dataset.coord(dim).units is not None:
+            new._units = dataset.coord(dim).units
         new._history = [
             f"Dataset resulting from application of `{method.__name__}` method"
         ]
